@@ -3,7 +3,7 @@ package HTTP::Tiny;
 use strict;
 use warnings;
 # ABSTRACT: A small, simple, correct HTTP/1.1 client
-our $VERSION = '0.036'; # VERSION
+our $VERSION = '0.039'; # VERSION
 
 use Carp ();
 
@@ -113,13 +113,16 @@ sub mirror {
         $args->{headers}{'if-modified-since'} ||= $self->_http_date($mtime);
     }
     my $tempfile = $file . int(rand(2**31));
-    open my $fh, ">", $tempfile
-        or Carp::croak(qq/Error: Could not open temporary file $tempfile for downloading: $!\n/);
+
+    require Fcntl;
+    sysopen my $fh, $tempfile, Fcntl::O_CREAT()|Fcntl::O_EXCL()|Fcntl::O_WRONLY()
+       or Carp::croak(qq/Error: Could not create temporary file $tempfile for downloading: $!\n/);
     binmode $fh;
     $args->{data_callback} = sub { print {$fh} $_[0] };
     my $response = $self->request('GET', $url, $args);
     close $fh
-        or Carp::croak(qq/Error: Could not close temporary file $tempfile: $!\n/);
+        or Carp::croak(qq/Error: Caught error closing temporary file $tempfile: $!\n/);
+
     if ( $response->{success} ) {
         rename $tempfile, $file
             or Carp::croak(qq/Error replacing $file with $tempfile: $!\n/);
@@ -309,7 +312,7 @@ sub _prepare_headers_and_cb {
     }
 
     # if we have Basic auth parameters, add them
-    if ( length $auth && ! defined $request->{headers}{authentication} ) {
+    if ( length $auth && ! defined $request->{headers}{authorization} ) {
         require MIME::Base64;
         $request->{headers}{authorization} =
             "Basic " . MIME::Base64::encode_base64($auth, "");
@@ -393,6 +396,8 @@ sub _split_url {
     $authority = (length($authority)) ? $authority : 'localhost';
     if ( $authority =~ /@/ ) {
         ($auth,$host) = $authority =~ m/\A([^@]*)@(.*)\z/;   # user:pass@host
+        # userinfo might be percent escaped, so recover real auth info
+        $auth =~ s/%([0-9A-Fa-f]{2})/chr(hex($1))/eg;
     }
     else {
         $host = $authority;
@@ -1000,7 +1005,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -1008,7 +1013,7 @@ HTTP::Tiny - A small, simple, correct HTTP/1.1 client
 
 =head1 VERSION
 
-version 0.036
+version 0.039
 
 =head1 SYNOPSIS
 
@@ -1189,6 +1194,11 @@ redirected request.) For example:
 
     $http->request('GET', 'http://Aladdin:open sesame@example.com/');
 
+If the "user:password" stanza contains reserved characters, they must
+be percent-escaped:
+
+    $http->request('GET', 'http://john%40example.com:password@example.com/');
+
 A hashref of options may be appended to modify the request.
 
 Valid options are:
@@ -1473,12 +1483,20 @@ There is no support for IPv6 of any kind.
 
 =back
 
+Despite the limitations listed above, HTTP::Tiny is considered nearly
+feature-complete.  If there are enhancements unrelated to the underlying
+transport, please consider them for L<HTTP::Tiny::UA> instead.
+
 =head1 SEE ALSO
 
 =over 4
 
 =item *
 
+L<HTTP::Tiny::UA> — Higher level UA features for HTTP::Tiny
+
+=item *
+
 L<HTTP::Thin> - HTTP::Tiny wrapper with L<HTTP::Request>/L<HTTP::Response> compatibility
 
 =item *
@@ -1594,6 +1612,10 @@ Mike Doherty <doherty@cpan.org>
 
 =item *
 
+Petr Písař <ppisar@redhat.com>
+
+=item *
+
 Serguei Trouchelle <stro@cpan.org>
 
 =item *
