@@ -186,15 +186,15 @@ Perl_new_ctype(pTHX_ const char *newctype)
 {
 #ifdef USE_LOCALE_CTYPE
     dVAR;
-    int i;
+    UV i;
 
     PERL_ARGS_ASSERT_NEW_CTYPE;
 
     for (i = 0; i < 256; i++) {
-	if (isUPPER_LC(i))
-	    PL_fold_locale[i] = toLOWER_LC(i);
-	else if (isLOWER_LC(i))
-	    PL_fold_locale[i] = toUPPER_LC(i);
+	if (isUPPER_LC((U8) i))
+	    PL_fold_locale[i] = toLOWER_LC((U8) i);
+	else if (isLOWER_LC((U8) i))
+	    PL_fold_locale[i] = toUPPER_LC((U8) i);
 	else
 	    PL_fold_locale[i] = i;
     }
