@@ -6,8 +6,8 @@ afs='false'
 afsroot='/afs'
 alignbytes='4'
 aphostname='/bin/hostname'
-archlib='/usr/local/lib/perl5/5.17/unknown'
-archlibexp='/usr/local/lib/perl5/5.17/unknown'
+archlib='/usr/local/lib/perl5/5.19/unknown'
+archlibexp='/usr/local/lib/perl5/5.19/unknown'
 archname='unknown'
 asctime_r_proto='0'
 bin='/usr/local/bin'
@@ -488,10 +488,9 @@ db_prefixtype='size_t'
 db_version_major='0'
 db_version_minor='0'
 db_version_patch='0'
-defvoidused=1
 direntrytype='struct dirent'
 doublesize='8'
-drand01="((rand() & 0x7FFF) / (double) ((unsigned long)1 << 15))"
+drand01="Perl_drand48()"
 drand48_r_proto='0'
 dtrace=''
 eagain='EAGAIN'
@@ -553,7 +552,6 @@ i_crypt='undef'
 i_db='undef'
 i_dbm='undef'
 i_dirent='define'
-i_dld='undef'
 i_dlfcn='undef'
 i_fcntl='undef'
 i_float='undef'
@@ -684,17 +682,17 @@ package='perl5'
 perl_static_inline='static'
 phostname='hostname'
 pidtype=int
-privlib='/usr/local/lib/perl5/5.17'
-privlibexp='/usr/local/lib/perl5/5.17'
+privlib='/usr/local/lib/perl5/5.19'
+privlibexp='/usr/local/lib/perl5/5.19'
 procselfexe=''
 prototype='undef'
 ptrsize='4'
 quadkind='4'
 quadtype='int64_t'
 randbits='48'
-randfunc='drand48'
+randfunc='Perl_drand48'
 random_r_proto='0'
-randseedtype='int'
+randseedtype='U32'
 rd_nodata='-1'
 readdir64_r_proto='0'
 readdir_r_proto='0'
@@ -718,7 +716,7 @@ sSCNfldbl='"llf"'
 sched_yield='sched_yield()'
 scriptdir='/usr/local/bin'
 scriptdirexp='/usr/local/bin'
-seedfunc='srand'
+seedfunc='Perl_drand48_init'
 selectminbits='32'
 selecttype=int
 setgrent_r_proto='0'
@@ -735,11 +733,11 @@ sig_name_init='0'
 sig_num_init='0'
 sig_size='1'
 signal_t=int
-sitearch='/usr/local/lib/perl5/5.17/unknown'
-sitearchexp='/usr/local/lib/perl5/5.17/unknown'
-sitelib='/usr/local/lib/perl5/5.17'
+sitearch='/usr/local/lib/perl5/5.19/unknown'
+sitearchexp='/usr/local/lib/perl5/5.19/unknown'
+sitelib='/usr/local/lib/perl5/5.19'
 sitelib_stem='/usr/local/lib/perl5'
-sitelibexp='/usr/local/lib/perl5/5.17'
+sitelibexp='/usr/local/lib/perl5/5.19'
 sizesize=4
 sizetype='size_t'
 socksizetype='int'
@@ -818,5 +816,4 @@ vendorarchexp=''
 vendorlib_stem=''
 vendorlibexp=''
 versiononly='undef'
-voidflags=1
 zip=''
