@@ -17,6 +17,8 @@
 #include "../patchlevel.h"
 #endif
 #include "util.h"
+#include "../unicode_constants.h"
+#define DELETE_CHAR DEL_NATIVE
 
 const char *filename;
 const char *myname;
@@ -29,10 +31,10 @@ int oper2(int type, int arg1, int arg2);
 int oper3(int type, int arg1, int arg2, int arg3);
 int oper4(int type, int arg1, int arg2, int arg3, int arg4);
 int oper5(int type, int arg1, int arg2, int arg3, int arg4, int arg5);
-STR *walk(int useval, int level, register int node, int *numericptr, int minprec);
+STR *walk(int useval, int level, int node, int *numericptr, int minprec);
 #ifdef NETWARE
 char *savestr(char *str);
-char *cpy2(register char *to, register char *from, register int delim);
+char *cpy2(char *to, char *from, int delim);
 #endif
 
 #if defined(OS2) || defined(WIN32) || defined(NETWARE)
@@ -54,12 +56,8 @@ usage()
 }
 #endif
 
-#ifdef __osf__
-#pragma message disable (mainparm) /* We have the envp in main(). */
-#endif
-
 int
-main(register int argc, register const char **argv, register const char **env)
+main(int argc, const char **argv)
 {
     STR *str;
     int i;
@@ -289,11 +287,7 @@ yylex(void)
     case ':':
 	tmp = *s++;
 	XOP(tmp);
-#ifdef EBCDIC
-    case 7:
-#else
-    case 127:
-#endif
+    case DELETE_CHAR:
 	s++;
 	XTERM('}');
     case '}':
@@ -826,7 +820,7 @@ yylex(void)
 }
 
 char *
-scanpat(register char *s)
+scanpat(char *s)
 {
     char *d;
 
@@ -878,7 +872,7 @@ yyerror(const char *s)
 }
 
 char *
-scannum(register char *s)
+scannum(char *s)
 {
     char *d;
 
